==> haskell-chell-0.5.0.2-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell
version:              0.5.0.2
visibility:           public
id:                   chell-0.5.0.2-E1vaa39ghvwHAvmrW5J7dq
key:                  chell-0.5.0.2-E1vaa39ghvwHAvmrW5J7dq
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing.
    It natively supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

category:             Testing
abi:                  27306343e4c168484d78b73616c2bbf0
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell
hs-libraries:         HSchell-0.5.0.2-E1vaa39ghvwHAvmrW5J7dq
depends:
    ansi-terminal-1.0.2-FTkVGNDxEfy5jKOkYDwQmU base-4.17.2.1
    bytestring-0.11.5.3 options-1.2.1.2-FxvvxtV5LiDD2OE6lMR4lF
    patience-0.3-76KPiSxHJ2U3wboHHGuXu
    random-1.2.1.3-53eBMyqCn4j5j5sTN6ACJa template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-0.5.0.2-86-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-chell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell
version:              0.5.0.2
visibility:           public
id:                   chell-0.5.0.2-K4HSeLvX5Th7iv6ZiY0CjJ
key:                  chell-0.5.0.2-K4HSeLvX5Th7iv6ZiY0CjJ
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             A simple and intuitive library for automated testing.
description:
    Chell is a simple and intuitive library for automated testing.
    It natively supports assertion-based testing, and can use companion libraries
    such as @chell-quickcheck@ to support more complex testing strategies.

category:             Testing
abi:                  925c4b2db642aa83e097f35366a8bb04
exposed:              True
exposed-modules:      Test.Chell
hidden-modules:       Test.Chell.Main Test.Chell.Output Test.Chell.Types
import-dirs:          /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/chell-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell
hs-libraries:         HSchell-0.5.0.2-K4HSeLvX5Th7iv6ZiY0CjJ
depends:
    ansi-terminal-1.0.2-Bnl76ueL4Li3NnUVLDNwn4 base-4.17.2.1
    bytestring-0.11.5.3 options-1.2.1.2-D4EnSTOCj3X6CGmJfFkUt0
    patience-0.3-76KPiSxHJ2U3wboHHGuXu
    random-1.2.1.3-9Bk1Rk8uHFTJVqAMIpxjnc template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-chell/html/chell.haddock
haddock-html:         /usr/share/doc/haskell-chell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
